@@ -1044,3 +1044,135 @@ HTACCESS.
 	b.AssertFileContent("public/.htaccess", "HTACCESS")
 
 }
+
+func TestConfigLanguageCodeTopLevel(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+languageCode = "en-US"
+-- layouts/index.html --
+LanguageCode: {{ .Site.LanguageCode }}|{{ site.Language.LanguageCode }}|
+
+	
+`
+	b := NewIntegrationTestBuilder(
+		IntegrationTestConfig{
+			T:           t,
+			TxtarString: files,
+		},
+	).Build()
+
+	b.AssertFileContent("public/index.html", "LanguageCode: en-US|en-US|")
+
+}
+
+func TestConfigMiscPanics(t *testing.T) {
+	t.Parallel()
+
+	// Issue 11047,
+	t.Run("empty params", func(t *testing.T) {
+
+		files := `
+-- hugo.yaml --
+params:
+-- layouts/index.html --
+Foo: {{ site.Params.foo }}|
+	
+		
+	`
+		b := NewIntegrationTestBuilder(
+			IntegrationTestConfig{
+				T:           t,
+				TxtarString: files,
+			},
+		).Build()
+
+		b.AssertFileContent("public/index.html", "Foo: |")
+	})
+
+	// Issue 11046
+	t.Run("invalid language setup", func(t *testing.T) {
+
+		files := `
+-- hugo.toml --
+baseURL = "https://example.org"
+languageCode = "en-us"
+title = "Blog of me"
+defaultContentLanguage = "en"
+
+[languages]
+	[en]
+	lang = "en"
+	languageName = "English"
+	weight = 1
+-- layouts/index.html --
+Foo: {{ site.Params.foo }}|
+	
+		
+	`
+		b, err := NewIntegrationTestBuilder(
+			IntegrationTestConfig{
+				T:           t,
+				TxtarString: files,
+			},
+		).BuildE()
+
+		b.Assert(err, qt.IsNotNil)
+		b.Assert(err.Error(), qt.Contains, "no languages")
+	})
+
+	// Issue 11044
+	t.Run("invalid defaultContentLanguage", func(t *testing.T) {
+
+		files := `
+-- hugo.toml --
+baseURL = "https://example.org"
+defaultContentLanguage = "sv"
+
+[languages]
+[languages.en]
+languageCode = "en"
+languageName = "English"
+weight = 1
+
+	
+		
+	`
+		b, err := NewIntegrationTestBuilder(
+			IntegrationTestConfig{
+				T:           t,
+				TxtarString: files,
+			},
+		).BuildE()
+
+		b.Assert(err, qt.IsNotNil)
+		b.Assert(err.Error(), qt.Contains, "defaultContentLanguage does not match any language definition")
+	})
+
+}
+
+// Issue #11040
+func TestConfigModuleDefaultMountsInConfig(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+baseURL = "https://example.org"
+contentDir = "mycontent"
+-- layouts/index.html --
+Home.
+
+	
+`
+	b := NewIntegrationTestBuilder(
+		IntegrationTestConfig{
+			T:           t,
+			TxtarString: files,
+		},
+	).Build()
+
+	b.Assert(b.H.Configs.Base.Module.Mounts, qt.HasLen, 7)
+	b.Assert(b.H.Configs.LanguageConfigSlice[0].Module.Mounts, qt.HasLen, 7)
+
+}
