@@ -145,7 +145,7 @@ func refreshPathForPort(s string, port int) {
 
 // ServeJS serves the liverreload.js who's reference is injected into the page.
 func ServeJS(w http.ResponseWriter, r *http.Request) {
-	w.Header().Set("Content-Type", media.JavascriptType.Type())
+	w.Header().Set("Content-Type", media.Builtin.JavascriptType.Type)
 	w.Write(liveReloadJS())
 }
 
