@@ -1,4 +1,4 @@
-// Copyright 2019 The Hugo Authors. All rights reserved.
+// Copyright 2023 The Hugo Authors. All rights reserved.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -11,15 +11,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-// Package goldmark converts Markdown to HTML using Goldmark.
-package goldmark
+package goldmark_test
 
 import (
 	"strings"
 	"testing"
 
+	"github.com/gohugoio/hugo/config/testconfig"
 	"github.com/gohugoio/hugo/markup/converter/hooks"
-	"github.com/gohugoio/hugo/markup/markup_config"
+	"github.com/gohugoio/hugo/markup/goldmark"
 
 	"github.com/gohugoio/hugo/common/loggers"
 
@@ -53,10 +53,10 @@ And then some.
 #### First H4
 
 `
-	p, err := Provider.New(
+	p, err := goldmark.Provider.New(
 		converter.ProviderConfig{
-			MarkupConfig: markup_config.Default,
-			Logger:       loggers.NewErrorLogger(),
+			Conf:   testconfig.GetTestConfig(nil, nil),
+			Logger: loggers.NewErrorLogger(),
 		})
 	c.Assert(err, qt.IsNil)
 	conv, err := p.New(converter.DocumentContext{})
@@ -83,23 +83,15 @@ And then some.
 func TestEscapeToc(t *testing.T) {
 	c := qt.New(t)
 
-	defaultConfig := markup_config.Default
-
-	safeConfig := defaultConfig
-	unsafeConfig := defaultConfig
-
-	safeConfig.Goldmark.Renderer.Unsafe = false
-	unsafeConfig.Goldmark.Renderer.Unsafe = true
-
-	safeP, _ := Provider.New(
+	safeP, _ := goldmark.Provider.New(
 		converter.ProviderConfig{
-			MarkupConfig: safeConfig,
-			Logger:       loggers.NewErrorLogger(),
+			Conf:   safeConf(),
+			Logger: loggers.NewErrorLogger(),
 		})
-	unsafeP, _ := Provider.New(
+	unsafeP, _ := goldmark.Provider.New(
 		converter.ProviderConfig{
-			MarkupConfig: unsafeConfig,
-			Logger:       loggers.NewErrorLogger(),
+			Conf:   unsafeConf(),
+			Logger: loggers.NewErrorLogger(),
 		})
 	safeConv, _ := safeP.New(converter.DocumentContext{})
 	unsafeConv, _ := unsafeP.New(converter.DocumentContext{})
